@@ -40,8 +40,6 @@ class SupportedFramework(ExtendedEnum):
     TENSORFLOW = 'tensorflow'
 
 
-class PartURI(ExtendedEnum):
-    IMAGE_CLASSIFICATION = 'ic/ais/ImageClassification'
-    IMAGE_SEGMENTATION = 'is/ais/IMAGESEGMENTATION'
-    TIMESERIES_FORECAST = 'tsf/ais/TIMESERIESFORECAST'
-    NLP = 'nlp/ais/NLP'
+class ResponseStatus(ExtendedEnum):
+    SUCCESS = 'success'
+    FAILED = 'failed'
